@@ -30,10 +30,11 @@
 
 #include "Rinternals.h"
 #include "Rgraphics.h"
+#include "Rdevices.h"
 #include "R_ext/GraphicsDevice.h"
 #include "R_ext/GraphicsEngine.h"
 
-        /* device-specific information per SVG device */
+/* device-specific information per SVG device */
 
 #define DOTSperIN       72.27
 #define in2dots(x)      (DOTSperIN * x)
@@ -185,9 +186,6 @@ static void   SVG_Size(double *left, double *right,
                        double *bottom, double *top,
                        NewDevDesc *dd);
 
-static void   SVG_Resize(double *left, double *right,
-                         double *bottom, double *top,
-                         NewDevDesc *dd);
 static double SVG_StrWidth(char *str,
                            R_GE_gcontext *gc,
                            NewDevDesc *dd);
@@ -396,13 +394,13 @@ static Rboolean SVG_Open(NewDevDesc *dd, SVGDesc *ptd)
   ptd->bg = dd->startfill;
   ptd->col = ptd->fg;
 
-  if (!((int)(ptd->texfp) = R_fopen(R_ExpandFileName(ptd->filename), "w")))
+  if (!( ptd->texfp = (FILE *) fopen(R_ExpandFileName(ptd->filename), "w") ))
     return FALSE;
 
   if(ptd->xmlHeader)
-    fprintf(ptd->texfp,"<?xml version=\"1.0\" standalone=\"yes\"?>\n");
+    fprintf(ptd->texfp,"<?xml version=\"1.0\"?>\n");
 
-  fprintf(ptd->texfp,"<svg width=\"%.2f\" height=\"%.2f\" ",
+  fprintf(ptd->texfp,"<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"%.2f\" height=\"%.2f\" ",
           in2dots(ptd->width), in2dots(ptd->height));
   fprintf(ptd->texfp,"viewBox=\"0,0,%.2f,%.2f\">\n",
           in2dots(ptd->width), in2dots(ptd->height));
@@ -423,15 +421,6 @@ static Rboolean SVG_Open(NewDevDesc *dd, SVGDesc *ptd)
 }
 
 
-/* Interactive Resize */
-
-static void SVG_Resize(double *left, double *right,
-                       double *bottom, double *top,
-                       NewDevDesc *dd)
-{
-
-}
-
 static void SVG_Clip(double x0, double x1, double y0, double y1,
                      NewDevDesc *dd)
 {
@@ -457,8 +446,8 @@ static void SVG_NewPage(R_GE_gcontext *gc, NewDevDesc *dd)
 
       fprintf(ptd->texfp,"</svg>\n");
       if(ptd->xmlHeader)
-        fprintf(ptd->texfp,"<?xml version=\"1.0\" encoding=\"iso-8859-1\"?>\n");
-      fprintf(ptd->texfp,"<svg width=\"%.2f\" height=\"%.2f\" ",
+          fprintf(ptd->texfp,"<?xml version=\"1.0\"?>\n");
+      fprintf(ptd->texfp,"<svg xmlns=\"http://www.w3.org/2000/svg\" width=\"%.2f\" height=\"%.2f\" ",
             in2dots(ptd->width), in2dots(ptd->height));
       fprintf(ptd->texfp,"viewBox=\"0,0,%.2f,%.2f\">\n",
             in2dots(ptd->width), in2dots(ptd->height));
@@ -684,8 +673,8 @@ Rboolean SVGDeviceDriver(NewDevDesc *dd, char *filename, char *bg, char *fg,
 
     strcpy(ptd->filename, filename);
 
-    dd->startfill = Rf_str2col(bg);
-    dd->startcol = Rf_str2col(fg);
+    dd->startfill = R_GE_str2col(bg);
+    dd->startcol = R_GE_str2col(fg);
     dd->startps = 10;
     dd->startlty = 0;
     dd->startfont = 1;
@@ -774,7 +763,7 @@ static  GEDevDesc *RSvgDevice(char **file, char **bg, char **fg,
     R_CheckDeviceAvailable();
     BEGIN_SUSPEND_INTERRUPTS {
         if (!(dev = (NewDevDesc *) Calloc(1,NewDevDesc)))
-            return;
+            error("unable to allocate memory for NewDevDesc");
         /* Do this for early redraw attempts */
         dev->displayList = R_NilValue;
 
